/// Model class for Android config.
///
/// Contains crucial data that are passed to native side in order to secure Android device.
class AndroidConfig {
  // Nullable because of older Dart SDK versions
  // see issue https://github.com/talsec/Free-RASP-Flutter/issues/6
  final String? expectedPackageName;
  final String? expectedSigningCertificateHash;
  final List<String>? supportedAlternativeStores;

  /// Constructor checks whether [expectedPackageName] and
  /// [expectedSigningCertificateHash] are provided.
  /// Both arguments are MANDATORY.
  AndroidConfig({
    required this.expectedPackageName,
    required this.expectedSigningCertificateHash,
    this.supportedAlternativeStores = const <String>[],
  }) : assert(
          expectedPackageName != null &&
              expectedSigningCertificateHash != null &&
              supportedAlternativeStores != null,
          'expectedPackageName and expectedSigningHash cannot be null, supportedAlternativeStores cannot be null but can be empty.',
        );
}
