import 'package:flutter_test/flutter_test.dart';
import 'package:freerasp/android/android_config.dart';

void main() {
  AndroidConfig createConfiguration(String? packageName, String? signingHash,
      List<String>? alternativeStores) {
    return AndroidConfig(
      expectedPackageName: packageName,
      expectedSigningCertificateHash: signingHash,
      supportedAlternativeStores: alternativeStores,
    );
  }

  AndroidConfig createDefaultConfiguration(
      String? packageName, String? signingHash) {
    return AndroidConfig(
      expectedPackageName: packageName,
      expectedSigningCertificateHash: signingHash,
    );
  }

  const String packageName = 'packageName';
  const String signingHash = 'signingHash';
  const List<String> alternativeStores = ['someAppStore'];

  test('Object should be created', () {
    expect(
        () => createConfiguration(packageName, signingHash, alternativeStores),
        returnsNormally);
  });

  test('Only expectedPackageName is provided', () {
    expect(() => createConfiguration(packageName, null, alternativeStores),
        throwsAssertionError);
    expect(() => createConfiguration(packageName, signingHash, null),
        throwsAssertionError);
    expect(() => createConfiguration(packageName, null, null),
        throwsAssertionError);
  });

  test('Only expectedSigningHash is provided', () {
    expect(() => createConfiguration(null, signingHash, alternativeStores),
        throwsAssertionError);
    expect(() => createConfiguration(packageName, signingHash, null),
        throwsAssertionError);
    expect(() => createConfiguration(null, signingHash, null),
        throwsAssertionError);
  });

  test('Only alternativeStores is provided', () {
    expect(() => createConfiguration(null, signingHash, alternativeStores),
        throwsAssertionError);
    expect(() => createConfiguration(packageName, null, alternativeStores),
        throwsAssertionError);
    expect(() => createConfiguration(null, null, alternativeStores),
        throwsAssertionError);
  });

  test('Nothing is provided', () {
    expect(() => createConfiguration(null, null, null), throwsAssertionError);
  });

  test('Relying on default parameters', () {
    expect(() => createDefaultConfiguration(null, null), throwsAssertionError);
    expect(() => createDefaultConfiguration(packageName, null),
        throwsAssertionError);
    expect(() => createDefaultConfiguration(null, signingHash),
        throwsAssertionError);
    expect(() => createDefaultConfiguration(packageName, signingHash),
        returnsNormally);
  });
}
